@@ -1,6 +1,10 @@
+from isodata.utils import list_isos, get_iso, make_availability_table
+from isodata import tests
 from isodata.version import __version__
 import isodata.base
 
+import isodata.utils
+
 from isodata.nyiso import NYISO
 from isodata.caiso import CAISO
 from isodata.ercot import Ercot
@@ -8,3 +12,5 @@ from isodata.isone import ISONE
 from isodata.miso import MISO
 from isodata.spp import SPP
 from isodata.pjm import PJM
+
+all_isos = [NYISO, CAISO, Ercot, ISONE, MISO, SPP, PJM]
