@@ -3,10 +3,12 @@ import pandas as pd
 
 
 class SPP(ISOBase):
+    name = "Southwest Power Pool"
+    iso_id = "spp"
 
-    def get_fuel_mix(self):
+    def get_latest_fuel_mix(self):
         url = "https://marketplace.spp.org/chart-api/gen-mix/asChart"
-        r = self.get_json(url)["response"]
+        r = self._get_json(url)["response"]
 
         data = {
             "Timestamp":  r["labels"]
@@ -17,6 +19,6 @@ class SPP(ISOBase):
 
         current_mix = historical_mix.iloc[0].to_dict()
 
-        time = current_mix.pop("Timestamp")
+        time = pd.Timestamp(current_mix.pop("Timestamp"))
 
-        return FuelMix(time=time, mix=current_mix)
+        return FuelMix(time=time, mix=current_mix, iso=self.name)
